<?php

/*
 * Checking session status
 * @return bool
 */

function is_session_started() {
    if (php_sapi_name() !== 'cli') {
        if (version_compare(phpversion(), '5.4.0', '>=')) {
            return session_status() === PHP_SESSION_ACTIVE ? TRUE : FALSE;
        } else {
            return session_id() === '' ? FALSE : TRUE;
        }
    }
    return FALSE;
}

/*
 * Encode an array in json
 */

function json_response($data) {
    header('Content-Type: application/json');
    echo json_encode($data);
    exit;
}

/*
 * Manage the expiration of the session
 */

function managementSession() {
    if (is_session_started() === FALSE) {
        session_start();
    }
    $time = $_SESSION['timeout']; // Timeout in seconds
// It is verified that the session variable 'user' created when making a correct login exists
    if (isset($_SESSION["user"])) {
// It is checked if the session variable 'expire' that controls the time exists. If it exists and the time is greater than $ time, we expire the session
        if (isset($_SESSION["expire"]) && time() > $_SESSION["expire"] + $time) {
            unset($_SESSION["expire"]);
            unset($_SESSION["user"]);
        }
// if it doesn't exist we create it
        else {
            $_SESSION["expire"] = time();
        }
    }

    if (!isset($_SESSION['user'])) {
        session_destroy();
        header("Location:https://" . $_SERVER['HTTP_HOST'] . "/index.html");
    }
}

/*
 * Check user role
 */

function checkRoleUser($conn, $role_id) {
    $sql = "SELECT * FROM roles WHERE role_id = $role_id";
    $stmt = selectStmt($conn, $sql);
    $role = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($role['backoffice_user'] == 0) {
        header("Location:https://" . $_SERVER['HTTP_HOST'] . "/itsm/dist/control/destroy.php");
    }
}

function getOS($user_agent) {
    $os_array = array(
        '/windows nt 10/i' => 'Windows 10',
        '/windows nt 6.3/i' => 'Windows 8.1',
        '/windows nt 6.2/i' => 'Windows 8',
        '/windows nt 6.1/i' => 'Windows 7',
        '/windows nt 6.0/i' => 'Windows Vista',
        '/windows nt 5.2/i' => 'Windows Server 2003/XP x64',
        '/windows nt 5.1/i' => 'Windows XP',
        '/windows xp/i' => 'Windows XP',
        '/windows nt 5.0/i' => 'Windows 2000',
        '/windows me/i' => 'Windows ME',
        '/win98/i' => 'Windows 98',
        '/win95/i' => 'Windows 95',
        '/win16/i' => 'Windows 3.11',
        '/macintosh|mac os x/i' => 'Mac OS X',
        '/mac_powerpc/i' => 'Mac OS 9',
        '/linux/i' => 'Linux',
        '/ubuntu/i' => 'Ubuntu',
        '/iphone/i' => 'iPhone',
        '/ipod/i' => 'iPod',
        '/ipad/i' => 'iPad',
        '/android/i' => 'Android',
        '/blackberry/i' => 'BlackBerry',
        '/webos/i' => 'Mobile'
    );
    //
    $os_platform = "Unknown OS Platform";
    foreach ($os_array as $regex => $value) {
        if (preg_match($regex, $user_agent)) {
            $os_platform = $value;
        }
    }
    return $os_platform;
}

/*
 * Get the visitor's browser
 */

function getBrowser($user_agent) {
    $browser_array = array(
        '/msie/i' => 'Internet Explorer',
        '/firefox/i' => 'Firefox',
        '/safari/i' => 'Safari',
        '/chrome/i' => 'Chrome',
        '/edge/i' => 'Edge',
        '/opera/i' => 'Opera',
        '/netscape/i' => 'Netscape',
        '/maxthon/i' => 'Maxthon',
        '/konqueror/i' => 'Konqueror',
        '/mobile/i' => 'Handheld Browser'
    );
    $browser = "Unknown Browser";
    foreach ($browser_array as $regex => $value) {
        if (preg_match($regex, $user_agent)) {
            $browser = $value;
        }
    }
    return $browser;
}

/*
 * Get categories of the selected catalog
 */

function categories($conn, $catalog) {

    if ($catalog == 'all') {
        $sql = "SELECT * FROM categories WHERE parent_category_id IS NULL";
    } else {
        $sql = "SELECT * FROM categories WHERE parent_category_id IS NULL AND name = '$catalog'";
    }

    $stmt = selectStmt($conn, $sql);
    $cats = $stmt->fetchAll(PDO::FETCH_ASSOC);

    $categories = array();

    foreach ($cats AS $row) {
        $categories[] = array(
            'category_id' => $row['category_id'],
            'parent_category_id' => $row['parent_category_id'],
            'name' => $row['name'],
            'selectable' => $row['selectable'],
            'subcategory' => sub_categories($row['category_id'], $conn),
        );
    }

    return $categories;
}

/*
 * Get categories of the selected parent category
 */

function sub_categories($idcat, $conn) {

    $sql = "SELECT * FROM categories WHERE parent_category_id=$idcat";
    $stmt = selectStmt($conn, $sql);
    $cats = $stmt->fetchAll(PDO::FETCH_ASSOC);

    $categories = array();

    foreach ($cats AS $row) {
        $categories[] = array(
            'category_id' => $row['category_id'],
            'parent_category_id' => $row['parent_category_id'],
            'name' => $row['name'],
            'selectable' => $row['selectable'],
            'subcategory' => sub_categories($row['category_id'], $conn),
        );
    }
    return $categories;
}

/*
 * Print subcategories
 */

function viewsubcat($categories) {
    $html = '<ul class="sub-category">';
    foreach ($categories as $category) {

        if ($category['selectable'] == 0) {
            $html .= '<li value="' . $category['category_id'] . '" name="' . $category['name'] . '">' . $category['name'] . '</li>';
        } else {
            $html .= '<a href="#"><li value="' . $category['category_id'] . '" onclick="setCategory($(this).attr(`value`),$(this).attr(`name`))" name="' . $category['name'] . '">' . $category['name'] . '</li></a>';
        }


        if (!empty($category['subcategory'])) {
            $html .= viewsubcat($category['subcategory']);
        }
    }
    $html .= '</ul>';

    return $html;
}

/*
 * Write log inbound mail
 */

function write_log_inbound_mail($from, $subject, $mail_date, $ticket) {
    $date = date('Y-m-d');
    $file = fopen("/home/francoto/domains/exys.francoto.es/public_html/logs/" . $date . "_inbound_mails.log", "a");
    $date = date('Y-m-d h:i:s');
    fwrite($file, "$date: Mail received. from: $from. Subject: $subject. Date: $mail_date. Ticket created: $ticket" . PHP_EOL);
    fclose($file);
}

/*
 * Write log task
 */

function write_log_task($date, $name, $msg) {
    $date = date('Y-m-d');
    $file = fopen("/home/francoto/domains/exys.francoto.es/public_html/logs/" . $date . "_task.log", "a");
    $date = date('Y-m-d h:i:s');
    fwrite($file, "Task: $name. Date: $date. Error Message: $msg" . PHP_EOL);
    fclose($file);
}

/*
 * Write log task
 */

function write_log_import($date, $name, $msg) {
    $date = date('Y-m-d');
    $file = fopen("/home/francoto/domains/exys.francoto.es/public_html/logs/" . $date . "_import.log", "a");
    $date = date('Y-m-d h:i:s');
    fwrite($file, "Import: $name. Date: $date. Error Message: $msg" . PHP_EOL);
    fclose($file);
}

/*
 * Generate a GUID
 */

function GUID() {
    if (function_exists('com_create_guid') === true) {
        return trim(com_create_guid(), '{}');
    }

    return sprintf('%04X%04X-%04X-%04X-%04X-%04X%04X%04X', mt_rand(0, 65535), mt_rand(0, 65535), mt_rand(0, 65535), mt_rand(16384, 20479), mt_rand(32768, 49151), mt_rand(0, 65535), mt_rand(0, 65535), mt_rand(0, 65535));
}

/*
 * Generate a randon number
 */

function randomNumber($length) {
    $result = '';

    for ($i = 0; $i < $length; $i++) {
        $result .= mt_rand(0, 9);
    }

    return $result;
}

/*
 * Send a mail reset password
 */

function mailResetPassword($conn, $email, $hash, $notification_id) {

    $notification = obtainNotification($conn, $notification_id);
    $smtp_setup = obtainSMTPData($conn);

    try {
        $mail = new PHPMailer\PHPMailer\PHPMailer();
        $mail->IsSMTP(); // enable SMTP

        $mail->SMTPDebug = 0; // debugging: 1 = errors and messages, 2 = messages only
        $mail->SMTPAuth = true; // authentication enabled
        $mail->SMTPSecure = $smtp_setup[0]; // secure transfer enabled REQUIRED for Gmail
        $mail->Host = $smtp_setup[1];
        $mail->Port = $smtp_setup[2]; // or 587
        $mail->IsHTML(true);
        $mail->Username = $smtp_setup[3];
        $mail->Password = $smtp_setup[4];
        $mail->SetFrom($smtp_setup[3]);
        $mail->AddAddress("$email");
        $mail->Subject = $notification['subject'];
        $notification['body'] = str_replace("%var_hash%", "$hash", $notification['body']);
        $notification['body'] = str_replace("../../../", "https://" . $_SERVER['HTTP_HOST'] . "/", $notification['body']);
        $mail->Body = $notification['body'];

        if (!$mail->Send()) {
            echo "Mailer Error: " . $mail->ErrorInfo;
        } else {
            echo "Message has been sent";
        }
    } catch (Exception $e) {
        /* PHPMailer exception. */
        echo $e->errorMessage();
    } catch (\Exception $e) {
        /* PHP exception (note the backslash to select the global namespace Exception class). */
        echo $e->getMessage();
    }
}

/*
 * Send a mail reset password Portal
 */

function mailResetPasswordPortal($conn, $email, $hash, $notification_id) {

    $notification = obtainNotification($conn, $notification_id);
    $smtp_setup = obtainSMTPData($conn);

    try {
        $mail = new PHPMailer\PHPMailer\PHPMailer();
        $mail->IsSMTP(); // enable SMTP

        $mail->SMTPDebug = 0; // debugging: 1 = errors and messages, 2 = messages only
        $mail->SMTPAuth = true; // authentication enabled
        $mail->SMTPSecure = $smtp_setup[0]; // secure transfer enabled REQUIRED for Gmail
        $mail->Host = $smtp_setup[1];
        $mail->Port = $smtp_setup[2]; // or 587
        $mail->IsHTML(true);
        $mail->Username = $smtp_setup[3];
        $mail->Password = $smtp_setup[4];
        $mail->SetFrom($smtp_setup[3]);
        $mail->AddAddress("$email");
        $mail->Subject = $notification['subject'];
        $notification['body'] = str_replace("%var_hash%", "$hash", $notification['body']);
        $notification['body'] = str_replace("../../../", "https://" . $_SERVER['HTTP_HOST'] . "/portal/", $notification['body']);
        $mail->Body = $notification['body'];

        if (!$mail->Send()) {
            echo "Mailer Error: " . $mail->ErrorInfo;
        } else {
            echo "Message has been sent";
        }
    } catch (Exception $e) {
        /* PHPMailer exception. */
        echo $e->errorMessage();
    } catch (\Exception $e) {
        /* PHP exception (note the backslash to select the global namespace Exception class). */
        echo $e->getMessage();
    }
}

/*
 * Send a mail ticket created
 */

function mailTicketCreated($conn, $ticket, $notification_id) {
    $notification = obtainNotification($conn, $notification_id);
    $smtp_setup = obtainSMTPData($conn);

    try {
        $mail = new PHPMailer\PHPMailer\PHPMailer();
        $mail->IsSMTP(); // enable SMTP

        $mail->SMTPDebug = 0; // debugging: 1 = errors and messages, 2 = messages only
        $mail->SMTPAuth = true; // authentication enabled
        $mail->SMTPSecure = $smtp_setup[0]; // secure transfer enabled REQUIRED for Gmail
        $mail->Host = $smtp_setup[1];
        $mail->Port = $smtp_setup[2]; // or 587
        $mail->IsHTML(true);
        $mail->Username = $smtp_setup[3];
        $mail->Password = $smtp_setup[4];
        $mail->SetFrom($smtp_setup[3]);
        if ($ticket["affected_user_notification"] == 1) {
            $mail->AddAddress($ticket["affected_user_email"]);
        }
        if ($ticket["requestor_user_notification"] == 1) {
            $mail->AddAddress($ticket["requestor_user_email"]);
        }
        $notification['subject'] = str_replace("%var_ticket_number%", $ticket['ticket_number'], $notification['subject']);
        $mail->Subject = $notification['subject'];
        $notification['body'] = str_replace("%var_ticket_number%", $ticket['ticket_number'], $notification['body']);
        $notification['body'] = str_replace("%var_affected_user%", $ticket['affected_user'], $notification['body']);
        $notification['body'] = str_replace("%var_creation_date%", $ticket['creation_date'], $notification['body']);
        $notification['body'] = str_replace("%var_category_name%", $ticket['category_name'], $notification['body']);
        $notification['body'] = str_replace("%var_status%", $ticket['status'], $notification['body']);
        $notification['body'] = str_replace("%var_title%", $ticket['title'], $notification['body']);
        $notification['body'] = str_replace("%var_description%", $ticket['description'], $notification['body']);
        $mail->Body = html_entity_decode($notification['body']);

        if (!$mail->Send()) {
            //echo "Mailer Error: " . $mail->ErrorInfo;
        } else {
            //echo "Message has been sent";
        }
    } catch (Exception $e) {
        /* PHPMailer exception. */
        echo $e->errorMessage();
    } catch (\Exception $e) {
        /* PHP exception (note the backslash to select the global namespace Exception class). */
        echo $e->getMessage();
    }
}

/*
 * Send a mail ticket closed
 */

function mailTicketTerminated($conn, $ticket, $notification_id) {
    $notification = obtainNotification($conn, $notification_id);
    $smtp_setup = obtainSMTPData($conn);

    try {
        $mail = new PHPMailer\PHPMailer\PHPMailer();
        $mail->IsSMTP(); // enable SMTP

        $mail->SMTPDebug = 0; // debugging: 1 = errors and messages, 2 = messages only
        $mail->SMTPAuth = true; // authentication enabled
        $mail->SMTPSecure = $smtp_setup[0]; // secure transfer enabled REQUIRED for Gmail
        $mail->Host = $smtp_setup[1];
        $mail->Port = $smtp_setup[2]; // or 587
        $mail->IsHTML(true);
        $mail->Username = $smtp_setup[3];
        $mail->Password = $smtp_setup[4];
        $mail->SetFrom($smtp_setup[3]);
        if ($ticket["affected_user_notification"] == 1) {
            $mail->AddAddress($ticket["affected_user_email"]);
        }
        if ($ticket["requestor_user_notification"] == 1) {
            $mail->AddAddress($ticket["requestor_user_email"]);
        }
        $notification['subject'] = str_replace("%var_ticket_number%", $ticket['ticket_number'], $notification['subject']);
        $mail->Subject = $notification['subject'];
        $notification['body'] = str_replace("%var_ticket_number%", $ticket['ticket_number'], $notification['body']);
        $notification['body'] = str_replace("%var_affected_user%", $ticket['affected_user'], $notification['body']);
        $notification['body'] = str_replace("%var_creation_date%", $ticket['creation_date'], $notification['body']);
        $notification['body'] = str_replace("%var_end_date%", $ticket['end_date'], $notification['body']);
        $notification['body'] = str_replace("%var_category_name%", $ticket['category_name'], $notification['body']);
        $notification['body'] = str_replace("%var_status%", $ticket['status'], $notification['body']);
        $notification['body'] = str_replace("%var_title%", $ticket['title'], $notification['body']);
        $notification['body'] = str_replace("%var_description%", $ticket['description'], $notification['body']);
        $notification['body'] = str_replace("%var_solution%", $ticket['solution'], $notification['body']);
        $mail->Body = html_entity_decode($notification['body']);

        if (!$mail->Send()) {
            //echo "Mailer Error: " . $mail->ErrorInfo;
        } else {
            //echo "Message has been sent";
        }
    } catch (Exception $e) {
        /* PHPMailer exception. */
        echo $e->errorMessage();
    } catch (\Exception $e) {
        /* PHP exception (note the backslash to select the global namespace Exception class). */
        echo $e->getMessage();
    }
}

/*
 * Send a mail ticket cancelled
 */

function mailTicketCancelled($conn, $ticket, $notification_id) {
    $notification = obtainNotification($conn, $notification_id);
    $smtp_setup = obtainSMTPData($conn);

    try {
        $mail = new PHPMailer\PHPMailer\PHPMailer();
        $mail->IsSMTP(); // enable SMTP

        $mail->SMTPDebug = 0; // debugging: 1 = errors and messages, 2 = messages only
        $mail->SMTPAuth = true; // authentication enabled
        $mail->SMTPSecure = $smtp_setup[0]; // secure transfer enabled REQUIRED for Gmail
        $mail->Host = $smtp_setup[1];
        $mail->Port = $smtp_setup[2]; // or 587
        $mail->IsHTML(true);
        $mail->Username = $smtp_setup[3];
        $mail->Password = $smtp_setup[4];
        $mail->SetFrom($smtp_setup[3]);
        if ($ticket["affected_user_notification"] == 1) {
            $mail->AddAddress($ticket["affected_user_email"]);
        }
        if ($ticket["requestor_user_notification"] == 1) {
            $mail->AddAddress($ticket["requestor_user_email"]);
        }
        $notification['subject'] = str_replace("%var_ticket_number%", $ticket['ticket_number'], $notification['subject']);
        $mail->Subject = $notification['subject'];
        $notification['body'] = str_replace("%var_ticket_number%", $ticket['ticket_number'], $notification['body']);
        $notification['body'] = str_replace("%var_affected_user%", $ticket['affected_user'], $notification['body']);
        $notification['body'] = str_replace("%var_creation_date%", $ticket['creation_date'], $notification['body']);
        $notification['body'] = str_replace("%var_end_date%", $ticket['end_date'], $notification['body']);
        $notification['body'] = str_replace("%var_category_name%", $ticket['category_name'], $notification['body']);
        $notification['body'] = str_replace("%var_status%", $ticket['status'], $notification['body']);
        $notification['body'] = str_replace("%var_title%", $ticket['title'], $notification['body']);
        $notification['body'] = str_replace("%var_description%", $ticket['description'], $notification['body']);
        $notification['body'] = str_replace("%var_reject_reason%", $ticket['reject_reason'], $notification['body']);
        $mail->Body = html_entity_decode($notification['body']);

        if (!$mail->Send()) {
            //echo "Mailer Error: " . $mail->ErrorInfo;
        } else {
            //echo "Message has been sent";
        }
    } catch (Exception $e) {
        /* PHPMailer exception. */
        echo $e->errorMessage();
    } catch (\Exception $e) {
        /* PHP exception (note the backslash to select the global namespace Exception class). */
        echo $e->getMessage();
    }
}

/*
 * Send a mail ticket comment added
 */

function mailTicketCommentAdded($conn, $ticket, $comment, $notification_id) {
    $notification = obtainNotification($conn, $notification_id);
    $smtp_setup = obtainSMTPData($conn);

    try {
        $mail = new PHPMailer\PHPMailer\PHPMailer();
        $mail->IsSMTP(); // enable SMTP

        $mail->SMTPDebug = 0; // debugging: 1 = errors and messages, 2 = messages only
        $mail->SMTPAuth = true; // authentication enabled
        $mail->SMTPSecure = $smtp_setup[0]; // secure transfer enabled REQUIRED for Gmail
        $mail->Host = $smtp_setup[1];
        $mail->Port = $smtp_setup[2]; // or 587
        $mail->IsHTML(true);
        $mail->Username = $smtp_setup[3];
        $mail->Password = $smtp_setup[4];
        $mail->SetFrom($smtp_setup[3]);
        if ($ticket["group_notification"] == 1) {
            $mail->AddAddress($ticket["group_email"]);
        }
        if ($ticket["assignee_user_notification"] == 1) {
            $mail->AddAddress($ticket["assignee_user_email"]);
        }
        $notification['subject'] = str_replace("%var_ticket_number%", $ticket['ticket_number'], $notification['subject']);
        $mail->Subject = $notification['subject'];
        $notification['body'] = str_replace("%var_ticket_number%", $ticket['ticket_number'], $notification['body']);
        $notification['body'] = str_replace("%var_comment%", $comment, $notification['body']);
        $mail->Body = html_entity_decode($notification['body']);

        if (!$mail->Send()) {
            //echo "Mailer Error: " . $mail->ErrorInfo;
        } else {
            //echo "Message has been sent";
        }
    } catch (Exception $e) {
        /* PHPMailer exception. */
        echo $e->errorMessage();
    } catch (\Exception $e) {
        /* PHP exception (note the backslash to select the global namespace Exception class). */
        echo $e->getMessage();
    }
}

/*
 * Send a mail ticket attchment added
 */

function mailTicketAttachmentAdded($conn, $ticket, $notification_id) {
    $notification = obtainNotification($conn, $notification_id);
    $smtp_setup = obtainSMTPData($conn);

    try {
        $mail = new PHPMailer\PHPMailer\PHPMailer();
        $mail->IsSMTP(); // enable SMTP

        $mail->SMTPDebug = 0; // debugging: 1 = errors and messages, 2 = messages only
        $mail->SMTPAuth = true; // authentication enabled
        $mail->SMTPSecure = $smtp_setup[0]; // secure transfer enabled REQUIRED for Gmail
        $mail->Host = $smtp_setup[1];
        $mail->Port = $smtp_setup[2]; // or 587
        $mail->IsHTML(true);
        $mail->Username = $smtp_setup[3];
        $mail->Password = $smtp_setup[4];
        $mail->SetFrom($smtp_setup[3]);
        if ($ticket["group_notification"] == 1) {
            $mail->AddAddress($ticket["group_email"]);
        }
        if ($ticket["assignee_user_notification"] == 1) {
            $mail->AddAddress($ticket["assignee_user_email"]);
        }
        $notification['subject'] = str_replace("%var_ticket_number%", $ticket['ticket_number'], $notification['subject']);
        $mail->Subject = $notification['subject'];
        $notification['body'] = str_replace("%var_ticket_number%", $ticket['ticket_number'], $notification['body']);
        $mail->Body = html_entity_decode($notification['body']);

        if (!$mail->Send()) {
            //echo "Mailer Error: " . $mail->ErrorInfo;
        } else {
            //echo "Message has been sent";
        }
    } catch (Exception $e) {
        /* PHPMailer exception. */
        echo $e->errorMessage();
    } catch (\Exception $e) {
        /* PHP exception (note the backslash to select the global namespace Exception class). */
        echo $e->getMessage();
    }
}

/*
 * Send a mail ticket attchment added
 */

function mailTicketAssigned($conn, $ticket, $notification_id) {
    $notification = obtainNotification($conn, $notification_id);
    $smtp_setup = obtainSMTPData($conn);

    try {
        $mail = new PHPMailer\PHPMailer\PHPMailer();
        $mail->IsSMTP(); // enable SMTP

        $mail->SMTPDebug = 0; // debugging: 1 = errors and messages, 2 = messages only
        $mail->SMTPAuth = true; // authentication enabled
        $mail->SMTPSecure = $smtp_setup[0]; // secure transfer enabled REQUIRED for Gmail
        $mail->Host = $smtp_setup[1];
        $mail->Port = $smtp_setup[2]; // or 587
        $mail->IsHTML(true);
        $mail->Username = $smtp_setup[3];
        $mail->Password = $smtp_setup[4];
        $mail->SetFrom($smtp_setup[3]);
        if ($ticket["group_notification"] == 1) {
            $mail->AddAddress($ticket["group_email"]);
        }
        if ($ticket["assignee_user_notification"] == 1) {
            $mail->AddAddress($ticket["assignee_user_email"]);
        }
        $notification['subject'] = str_replace("%var_ticket_number%", $ticket['ticket_number'], $notification['subject']);
        $mail->Subject = $notification['subject'];
        $notification['body'] = str_replace("%var_ticket_number%", $ticket['ticket_number'], $notification['body']);
        $notification['body'] = str_replace("%var_affected_user%", $ticket['affected_user'], $notification['body']);
        $notification['body'] = str_replace("%var_creation_date%", $ticket['creation_date'], $notification['body']);
        $notification['body'] = str_replace("%var_category_name%", $ticket['category_name'], $notification['body']);
        $notification['body'] = str_replace("%var_status%", $ticket['status'], $notification['body']);
        $notification['body'] = str_replace("%var_title%", $ticket['title'], $notification['body']);
        $notification['body'] = str_replace("%var_description%", $ticket['description'], $notification['body']);
        $notification['body'] = str_replace("%var_group_name%", $ticket['group_name'], $notification['body']);
        $mail->Body = html_entity_decode($notification['body']);

        if (!$mail->Send()) {
            //echo "Mailer Error: " . $mail->ErrorInfo;
        } else {
            //echo "Message has been sent";
        }
    } catch (Exception $e) {
        /* PHPMailer exception. */
        echo $e->errorMessage();
    } catch (\Exception $e) {
        /* PHP exception (note the backslash to select the global namespace Exception class). */
        echo $e->getMessage();
    }
}

/*
 * Generate Random String
 */

function generateRandomString($length = 20) {
    return substr(str_shuffle("0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"), 0, $length);
}

?>